@@ -21,8 +21,10 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfo_Internal_Const.h"
+#include "MediaInfo/HashWrapper.h" //For MEDIAINFO_HASH
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Config.h"
+    #include "MediaInfo/MediaInfo_Config_PerPackage.h"
     #include "MediaInfo/MediaInfo_Events.h"
     #include "ZenLib/File.h"
 #endif //MEDIAINFO_EVENTS
@@ -30,7 +32,6 @@
 #include "ZenLib/Translation.h"
 #include "ZenLib/InfoMap.h"
 using namespace ZenLib;
-using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -38,7 +39,6 @@ namespace MediaInfoLib
 
 #if MEDIAINFO_EVENTS
     class File__Analyze;
-    class MediaInfo_Config_PerPackage;
 #endif //MEDIAINFO_EVENTS
 
 #if MEDIAINFO_AES
@@ -129,6 +129,8 @@ public :
     #if MEDIAINFO_ADVANCED
         void          File_DefaultFrameRate_Set (float64 NewValue);
         float64       File_DefaultFrameRate_Get ();
+        void          File_DefaultTimeCode_Set (string NewValue);
+        string        File_DefaultTimeCode_Get ();
     #endif //MEDIAINFO_ADVANCED
 
     #if MEDIAINFO_ADVANCED
@@ -150,6 +152,10 @@ public :
         #endif //MEDIAINFO_ADVANCED
     #endif //MEDIAINFO_DEMUX
 
+    #if MEDIAINFO_HASH
+        void         File_Hash_Set (HashWrapper::HashFunctions Funtions);
+        HashWrapper::HashFunctions File_Hash_Get ();
+    #endif //MEDIAINFO_HASH
     #if MEDIAINFO_MD5
         void          File_Md5_Set (bool NewValue);
         bool          File_Md5_Get ();
@@ -252,6 +258,8 @@ public :
     void          Event_Send(File__Analyze* Source, const int8u* Data_Content, size_t Data_Size, const Ztring &File_Name=Ztring());
     void          Event_Accepted(File__Analyze* Source);
     void          Event_SubFile_Start(const Ztring &FileName_Absolute);
+    void          Event_SubFile_Missing(const Ztring &FileName_Relative);
+    void          Event_SubFile_Missing_Absolute(const Ztring &FileName_Absolute);
     #endif //MEDIAINFO_EVENTS
 
     #if MEDIAINFO_DEMUX
@@ -275,6 +283,9 @@ public :
     int64u        Demux_FirstFrameNumber_Get ();
     void          Demux_InitData_Set (int8u NewValue);
     int8u         Demux_InitData_Get ();
+    void          Demux_SplitAudioBlocks_Set(bool NewValue);
+    bool          Demux_SplitAudioBlocks_Get();
+    std::map<Ztring, File> Demux_Files;
     #endif //MEDIAINFO_DEMUX
 
     #if MEDIAINFO_IBIUSAGE
@@ -287,6 +298,10 @@ public :
     void          Ibi_Create_Set (bool NewValue);
     bool          Ibi_Create_Get ();
     #endif //MEDIAINFO_IBIUSAGE
+    #if MEDIAINFO_FIXITY
+    void          TryToFix_Set (bool NewValue);
+    bool          TryToFix_Get ();
+    #endif //MEDIAINFO_FIXITY
 
     //Specific
     void          File_MpegTs_ForceMenu_Set (bool NewValue);
@@ -319,6 +334,8 @@ public :
     #endif //MEDIAINFO_MACROBLOCKS
     void          File_GrowingFile_Delay_Set(float64 Value);
     float64       File_GrowingFile_Delay_Get();
+    void          File_GrowingFile_Force_Set(bool Value);
+    bool          File_GrowingFile_Force_Get();
     #if defined(MEDIAINFO_LIBCURL_YES)
     void          File_Curl_Set (const Ztring &NewValue);
     void          File_Curl_Set (const Ztring &Field, const Ztring &NewValue);
@@ -361,6 +378,9 @@ public :
     bool          File_DtvccTransport_Stream_IsPresent;
     bool          File_DtvccTransport_Descriptor_IsPresent;
     #endif //defined(MEDIAINFO_EIA608_YES) || defined(MEDIAINFO_EIA708_YES)
+    #if defined(MEDIAINFO_MPEGPS_YES)
+    bool          File_MpegPs_PTS_Begin_IsNearZero;
+    #endif //defined(MEDIAINFO_MPEGPS_YES)
     int64u        File_Current_Offset;
     int64u        File_Current_Size;
     int64u        File_IgnoreEditsBefore;
@@ -370,6 +390,7 @@ public :
     float32       ParseSpeed;
     #if MEDIAINFO_EVENTS
     MediaInfo_Config_PerPackage* Config_PerPackage;
+    bool          Events_TimestampShift_Disabled;
     Ztring        File_Names_RootDirectory;
     #endif //MEDIAINFO_EVENTS
     #if MEDIAINFO_DEMUX
@@ -403,6 +424,7 @@ private :
         bool                File_IgnoreSequenceFilesCount;
         int64u              File_SequenceFilesSkipFrames;
         float64             File_DefaultFrameRate;
+        string              File_DefaultTimeCode;
         bool                File_Source_List;
         bool                File_RiskyBitRateEstimation;
         bool                File_MergeBitRateInfo;
@@ -410,6 +432,9 @@ private :
             bool                File_Demux_Unpacketize_StreamLayoutChange_Skip;
         #endif //MEDIAINFO_DEMUX
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_HASH
+        HashWrapper::HashFunctions Hash_Functions;
+    #endif //MEDIAINFO_HASH
     #if MEDIAINFO_MD5
         bool                File_Md5;
     #endif //MEDIAINFO_MD5
@@ -479,6 +504,9 @@ private :
     int64u                  SubFile_StreamID;
     bool                    ParseUndecodableFrames;
     Ztring                  SubFile_IDs;
+    int64u                      Events_TimestampShift_Reference_PTS;
+    int64u                      Events_TimestampShift_Reference_ID;
+    std::vector<event_delayed*> Events_TimestampShift_Delayed;
     #endif //MEDIAINFO_EVENTS
 
     #if MEDIAINFO_DEMUX
@@ -488,6 +516,7 @@ private :
     bool                    Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10;
     bool                    Demux_Hevc_Transcode_Iso14496_15_to_AnnexB;
     bool                    Demux_Unpacketize;
+    bool                    Demux_SplitAudioBlocks;
     float64                 Demux_Rate;
     int64u                  Demux_FirstDts;
     int64u                  Demux_FirstFrameNumber;
@@ -501,6 +530,9 @@ private :
     #if MEDIAINFO_IBIUSAGE
     bool                    Ibi_Create;
     #endif //MEDIAINFO_IBIUSAGE
+    #if MEDIAINFO_FIXITY
+    bool                    TryToFix;
+    #endif //MEDIAINFO_SEEK
 
     //Specific
     bool                    File_MpegTs_ForceMenu;
@@ -521,6 +553,7 @@ private :
     bool                    File_Macroblocks_Parse;
     #endif //MEDIAINFO_MACROBLOCKS
     float64                 File_GrowingFile_Delay;
+    bool                    File_GrowingFile_Force;
     #if defined(MEDIAINFO_LIBMMS_YES)
     bool                    File_Mmsh_Describe_Only;
     #endif //defined(MEDIAINFO_LIBMMS_YES)
