@@ -285,6 +285,16 @@
         #define MEDIAINFO_DEMUX 1
     #endif
 #endif
+#if !defined(MEDIAINFO_DECODE)
+    #if defined(MEDIAINFO_DECODE_NO) && defined(MEDIAINFO_DECODE_YES)
+        #undef MEDIAINFO_DECODE_NO //MEDIAINFO_DECODE_YES has priority
+    #endif
+    #if defined(MEDIAINFO_DECODE_NO)
+        #define MEDIAINFO_DECODE 0
+    #else
+        #define MEDIAINFO_DECODE 1
+    #endif
+#endif
 #if MEDIAINFO_DEMUX && !MEDIAINFO_EVENTS
     pragma error MEDIAINFO_DEMUX can be set to 1 only if MEDIAINFO_EVENTS is set to 1
 #endif
@@ -322,6 +332,20 @@
         #define MEDIAINFO_READTHREAD 1
     #endif
 #endif
+#if !defined(MEDIAINFO_FIXITY)
+    #if defined(MEDIAINFO_FIXITY_NO) && defined(MEDIAINFO_FIXITY_YES)
+        #undef MEDIAINFO_FIXITY_NO //MEDIAINFO_FIXITY_YES has priority
+    #endif
+    #if defined(MEDIAINFO_FIXITY_NO)
+        #define MEDIAINFO_FIXITY 0
+    #else
+        #if MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 1
+        #else //MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 0
+        #endif //MEDIAINFO_ADVANCED
+    #endif
+#endif
 
 //***************************************************************************
 // Precise configuration
@@ -523,9 +547,15 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_UMF_NO) && !defined(MEDIAINFO_UMF_YES)
     #define MEDIAINFO_UMF_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_VBI_NO) && !defined(MEDIAINFO_VBI_YES)
+    #define MEDIAINFO_VBI_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_WM_NO) && !defined(MEDIAINFO_WM_YES)
     #define MEDIAINFO_WM_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_WTV_NO) && !defined(MEDIAINFO_WTV_YES)
+#define MEDIAINFO_WTV_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_XDCAM_NO) && !defined(MEDIAINFO_XDCAM_YES)
     #define MEDIAINFO_XDCAM_YES
 #endif
